@@ -38,7 +38,7 @@ class CitationsControllerSponsors extends \Hubzero\Component\AdminController
 {
 	/**
 	 * List types
-	 * 
+	 *
 	 * @return     void
 	 */
 	public function displayTask()
@@ -47,7 +47,7 @@ class CitationsControllerSponsors extends \Hubzero\Component\AdminController
 		$this->view->sponsors = $cs->getSponsor();
 
 		// Set any errors
-		if ($this->getError()) 
+		if ($this->getError())
 		{
 			foreach ($this->getErrors() as $error)
 			{
@@ -61,7 +61,7 @@ class CitationsControllerSponsors extends \Hubzero\Component\AdminController
 
 	/**
 	 * Create a new type
-	 * 
+	 *
 	 * @return     void
 	 */
 	public function addTask()
@@ -72,7 +72,7 @@ class CitationsControllerSponsors extends \Hubzero\Component\AdminController
 
 	/**
 	 * Edit a type
-	 * 
+	 *
 	 * @return     void
 	 */
 	public function editTask($row=null)
@@ -85,17 +85,21 @@ class CitationsControllerSponsors extends \Hubzero\Component\AdminController
 		{
 			$this->view->type = $row;
 		}
-		else 
+		else
 		{
 			// Incoming
 			$id = JRequest::getVar('id', array(0));
+			if (is_array($id))
+			{
+				$id = (!empty($id) ? $id[0] : 0);
+			}
 
 			$this->view->sponsor = new CitationsSponsor($this->database);
-			$this->view->sponsor = $this->view->sponsor->getSponsor($id[0]);
+			$this->view->sponsor = $this->view->sponsor->getSponsor($id);
 		}
 
 		// Set any errors
-		if ($this->getError()) 
+		if ($this->getError())
 		{
 			foreach ($this->getErrors() as $error)
 			{
@@ -106,10 +110,10 @@ class CitationsControllerSponsors extends \Hubzero\Component\AdminController
 		// Output the HTML
 		$this->view->display();
 	}
-	
+
 	/**
 	 * Save a type
-	 * 
+	 *
 	 * @return     void
 	 */
 	public function saveTask()
@@ -120,7 +124,7 @@ class CitationsControllerSponsors extends \Hubzero\Component\AdminController
 		$s = JRequest::getVar('sponsor', array(), 'post');
 
 		$row = new CitationsSponsor($this->database);
-		if (!$row->bind($s)) 
+		if (!$row->bind($s))
 		{
 			$this->addComponentMessage($row->getError(), 'error');
 			$this->view->setLayout('edit');
@@ -128,7 +132,7 @@ class CitationsControllerSponsors extends \Hubzero\Component\AdminController
 			return;
 		}
 
-		if (!$row->check()) 
+		if (!$row->check())
 		{
 			$this->addComponentMessage($row->getError(), 'error');
 			$this->view->setLayout('edit');
@@ -137,8 +141,8 @@ class CitationsControllerSponsors extends \Hubzero\Component\AdminController
 		}
 
 		// Store new content
-		//if (!$row->save($type)) 
-		if (!$row->store()) 
+		//if (!$row->save($type))
+		if (!$row->store())
 		{
 			$this->addComponentMessage($row->getError(), 'error');
 			$this->view->setLayout('edit');
@@ -148,13 +152,13 @@ class CitationsControllerSponsors extends \Hubzero\Component\AdminController
 
 		$this->setRedirect(
 			'index.php?option=' . $this->_option . '&controller=' . $this->_controller,
-			JText::_('Citation(s) successfully saved')
+			JText::_('CITATION_SPONSOR_SAVED')
 		);
 	}
 
 	/**
 	 * Remove one or more types
-	 * 
+	 *
 	 * @return     void
 	 */
 	public function removeTask()
@@ -164,13 +168,14 @@ class CitationsControllerSponsors extends \Hubzero\Component\AdminController
 
 		// Incoming (expecting an array)
 		$ids = JRequest::getVar('id', array());
+		$ids = (!is_array($ids) ? array($ids) : $ids);
 
 		// Ensure we have an ID to work with
-		if (empty($ids)) 
+		if (empty($ids))
 		{
 			$this->setRedirect(
 				'index.php?option=' . $this->_option . '&controller=' . $this->_controller,
-				JText::_('No citation sponsor selected.'),
+				JText::_('CITATION_NO_SPONSOR'),
 				'error'
 			);
 			return;
@@ -186,7 +191,7 @@ class CitationsControllerSponsors extends \Hubzero\Component\AdminController
 		// Redirect
 		$this->setRedirect(
 			'index.php?option=' . $this->_option . '&controller=' . $this->_controller,
-			JText::_('Citation sponsor(s) successfully removed.')
+			JText::_('CITATION_SPONSOR_REMOVED')
 		);
 	}
 
