@@ -32,9 +32,7 @@
 defined('_JEXEC') or die('Restricted access');
 
 /**
- *
  * Course section table class
- *
  */
 class CoursesTableSection extends JTable
 {
@@ -42,7 +40,7 @@ class CoursesTableSection extends JTable
 	 * ID, primary key for course instances table
 	 * int(11)
 	 *
-	 * @var int(11)
+	 * @var integer
 	 */
 	var $id = NULL;
 
@@ -140,8 +138,8 @@ class CoursesTableSection extends JTable
 	/**
 	 * Contructor method for JTable class
 	 *
-	 * @param  database object
-	 * @return void
+	 * @param   object  &$db  database object
+	 * @return  void
 	 */
 	public function __construct(&$db)
 	{
@@ -152,11 +150,11 @@ class CoursesTableSection extends JTable
 	 * Returns a reference to a CoursesTableSection object
 	 *
 	 * This method must be invoked as:
-	 *     $inst = CoursesInstance::getInstance($alias);
+	 *     $inst = CoursesTableSection::getInstance($alias);
 	 *
-	 * @param      string $pagename The page to load
-	 * @param      string $scope    The page scope
-	 * @return     object CoursesTableSection
+	 * @param   string  $pagename  The page to load
+	 * @param   string  $scope     The page scope
+	 * @return  object  CoursesTableSection
 	 */
 	public static function getInstance($type, $prefix = 'JTable', $config = array())
 	{
@@ -184,8 +182,8 @@ class CoursesTableSection extends JTable
 	/**
 	 * Load a record and bind to $this
 	 *
-	 * @param      string $oid Record alias
-	 * @return     boolean True on success
+	 * @param   string   $oid  Record alias
+	 * @return  boolean  True on success
 	 */
 	public function load($oid=NULL, $offering_id=null)
 	{
@@ -200,29 +198,26 @@ class CoursesTableSection extends JTable
 
 		if ($oid == '!!default!!')
 		{
-			$query = "SELECT * FROM $this->_tbl WHERE `is_default`=1 AND `offering_id`=" . $this->_db->Quote(intval($offering_id)) . " LIMIT 1";
+			$fields = array(
+				'is_default'  => 1,
+				'offering_id' => intval($offering_id)
+			);
 		}
 		else
 		{
-			$query = "SELECT * FROM $this->_tbl WHERE `alias`=" . $this->_db->Quote(trim($oid)) . " AND offering_id=" . $this->_db->Quote(intval($offering_id));
+			$fields = array(
+				'alias'       => trim($oid),
+				'offering_id' => intval($offering_id)
+			);
 		}
 
-		$this->_db->setQuery($query);
-		if ($result = $this->_db->loadAssoc())
-		{
-			return $this->bind($result);
-		}
-		else
-		{
-			$this->setError($this->_db->getErrorMsg());
-			return false;
-		}
+		return parent::load($fields);
 	}
 
 	/**
 	 * Override the check function to do a little input cleanup
 	 *
-	 * @return return true
+	 * @return  boolean
 	 */
 	public function check()
 	{
@@ -256,9 +251,8 @@ class CoursesTableSection extends JTable
 
 		if (!$this->id)
 		{
-			$juser = JFactory::getUser();
-			$this->created = JFactory::getDate()->toSql();
-			$this->created_by = $juser->get('id');
+			$this->created    = JFactory::getDate()->toSql();
+			$this->created_by = JFactory::getUser()->get('id');
 		}
 
 		return true;
@@ -267,8 +261,8 @@ class CoursesTableSection extends JTable
 	/**
 	 * Build query method
 	 *
-	 * @param  array $filters
-	 * @return $query database query
+	 * @param   array   $filters
+	 * @return  string  Database query
 	 */
 	private function _buildQuery($filters=array())
 	{
@@ -294,7 +288,15 @@ class CoursesTableSection extends JTable
 
 		if (isset($filters['enrollment']))
 		{
-			$where[] = "os.enrollment=" . $this->_db->Quote(intval($filters['enrollment']));
+			$filters['enrollment'] = array_map('intval', $filters['enrollment']);
+			if (is_array($filters['enrollment']))
+			{
+				$where[] = "os.enrollment IN (" . implode(',', $filters['enrollment']) . ")";
+			}
+			else
+			{
+				$where[] = "os.enrollment=" . $this->_db->Quote(intval($filters['enrollment']));
+			}
 		}
 
 		if (isset($filters['search']) && $filters['search'])
@@ -311,20 +313,47 @@ class CoursesTableSection extends JTable
 			$where[] = "(os.publish_down = '0000-00-00 00:00:00' OR os.publish_down >= " . $this->_db->Quote($now) . ")";
 		}
 
+		if (isset($filters['started']))
+		{
+			$now = JFactory::getDate()->toSql();
+
+			if ($filters['started'] === true)
+			{
+				$where[] = "(os.start_date = '0000-00-00 00:00:00' OR os.start_date <= " . $this->_db->Quote($now) . ")";
+			}
+			else if ($filters['started'] === false)
+			{
+				$where[] = "(os.start_date != '0000-00-00 00:00:00' AND os.start_date > " . $this->_db->Quote($now) . ")";
+			}
+		}
+
+		if (isset($filters['ended']))
+		{
+			$now = JFactory::getDate()->toSql();
+
+			if ($filters['ended'] === true)
+			{
+				$where[] = "(os.end_date != '0000-00-00 00:00:00' AND os.end_date < " . $this->_db->Quote($now) . ")";
+			}
+			else if ($filters['ended'] === false)
+			{
+				$where[] = "(os.end_date = '0000-00-00 00:00:00' OR os.end_date >= " . $this->_db->Quote($now) . ")";
+			}
+		}
+
 		if (count($where) > 0)
 		{
-			$query .= " WHERE ";
-			$query .= implode(" AND ", $where);
+			$query .= " WHERE " . implode(" AND ", $where);
 		}
 
 		return $query;
 	}
 
 	/**
-	 * Get a count of course offerings
+	 * Get a count of entries
 	 *
-	 * @param  array $filters
-	 * @return object Return course units
+	 * @param   array    $filters
+	 * @return  integer
 	 */
 	public function count($filters=array())
 	{
@@ -336,10 +365,10 @@ class CoursesTableSection extends JTable
 	}
 
 	/**
-	 * Get an object list of course units
+	 * Get a list of entries
 	 *
-	 * @param  array $filters
-	 * @return object Return course units
+	 * @param   array  $filters
+	 * @return  array
 	 */
 	public function find($filters=array())
 	{
