@@ -3,15 +3,15 @@
 defined('_JEXEC') or die( 'Restricted access' );
 
 JToolBarHelper::title(JText::_( 'COM_EVENTS' ).': '.JText::_('COM_EVENTS_RESPONDANTS'), 'user.png' );
-JToolBarHelper::custom('download', 'upload', JText::_('COM_EVENTS_DOWNLOAD_CSV'), JText::_('COM_EVENTS_DOWNLOAD_CSV'), false, false);
-JToolBarHelper::deleteList( '', 'remove', JText::_('Delete') );
+JToolBarHelper::custom('download', 'upload', 'COM_EVENTS_DOWNLOAD_CSV', 'COM_EVENTS_DOWNLOAD_CSV', false, false);
+JToolBarHelper::deleteList( '', 'remove', 'COM_EVENTS_DELETE' );
 JToolBarHelper::cancel();
 
 $rows = $this->resp->getRecords();
 $pageNav = $this->resp->getPaginator();
 ?>
 <script type="text/javascript">
-function submitbutton(pressbutton) 
+function submitbutton(pressbutton)
 {
 	var form = document.getElementById('adminForm');
 	if (pressbutton == 'cancel') {
@@ -25,7 +25,7 @@ function submitbutton(pressbutton)
 
 <form action="" method="post" name="adminForm" id="adminForm">
 	<h2><?php echo stripslashes($this->event->title); ?></h2>
-	
+
 	<fieldset id="filter-bar">
 		<label for="filter_search"><?php echo JText::_('COM_EVENTS_SEARCH'); ?>:</label>
 		<input type="text" name="search" id="filter_search" value="<?php echo $this->resp->getSearchTerms(); ?>" />
@@ -45,7 +45,7 @@ function submitbutton(pressbutton)
 		<input type="submit" value="<?php echo JText::_('COM_EVENTS_GO'); ?>" />
 	</fieldset>
 
-	<table class="adminlist" summary="<?php echo JText::_('TABLE_SUMMARY'); ?>">
+	<table class="adminlist">
 		<thead>
  			<tr>
 				<th scope="col"><input type="checkbox" name="toggle" value="" onclick="checkAll(<?php echo count( $rows );?>);" /></th>
@@ -70,7 +70,7 @@ foreach ($rows as $idx=>&$row)
 {
 	if (!@$row->id) continue;*/
 $k = 0;
-for ($i=0, $n=count( $rows ); $i < $n; $i++) 
+for ($i=0, $n=count( $rows ); $i < $n; $i++)
 {
 	$row = &$rows[$i];
 ?>
@@ -79,12 +79,14 @@ for ($i=0, $n=count( $rows ); $i < $n; $i++)
 				<td><a href="index.php?option=<?php echo $this->option ?>&amp;controller=<?php echo $this->controller; ?>&amp;task=respondent&amp;id=<?php echo $row->id; ?>&amp;event_id=<?php echo $this->event->id; ?>"><?php echo $this->escape(stripslashes($row->last_name . ', ' . $row->first_name)); ?></a></td>
 				<td><a href="mailto:<?php echo $row->email ?>"><?php echo $this->escape($row->email); ?></a></td>
 				<td><?php echo JHTML::_('date', $row->registered, JText::_('DATE_FORMAT_HZ1')); ?></td>
-				<td><?php 
-				if (!empty($row->dietary_needs)) {
-					echo 'Dietary needs: '.$this->escape($row->dietary_needs).'<br />';
+				<td><?php
+				if (!empty($row->dietary_needs))
+				{
+					echo JText::sprintf('COM_EVENTS_RESPONDANT_DIETARY_NEEDS', $this->escape($row->dietary_needs)) . '<br />';
 				}
-				if ($row->disability_needs) {
-					echo 'Disability consideration requested';
+				if ($row->disability_needs)
+				{
+					echo JText::_('COM_EVENTS_RESPONDANT_DISABILITY_REQUESTED');
 				}
 				?></td>
 				<td><?php echo $this->escape($row->comment); ?></td>
