@@ -133,6 +133,13 @@ class PublicationVersion extends JTable
 	 */
 	var $accepted					= NULL;
 
+	/**
+	 * datetime(0000-00-00 00:00:00)
+	 *
+	 * @var string
+	 */
+	var $archived					= NULL;
+
 	/**
 	 * varchar(100)
 	 *
@@ -266,6 +273,13 @@ class PublicationVersion extends JTable
 	 */
 	var $curation					= NULL;
 
+	/**
+	 * Assigned curator
+	 *
+	 * @var text
+	 */
+	var $curator					= NULL;
+
 	/**
 	 * Constructor
 	 *
@@ -304,7 +318,7 @@ class PublicationVersion extends JTable
 		{
 			$query.= " AND state=3 ";
 		}
-		elseif (intval($version))
+		elseif (is_numeric($version))
 		{
 			$query.= " AND version_number='".$version."' ";
 		}
@@ -363,7 +377,7 @@ class PublicationVersion extends JTable
 		{
 			$query.= " AND state=3 ";
 		}
-		elseif (intval($version))
+		elseif (is_numeric($version))
 		{
 			$query.= " AND version_number='".$version."' ";
 		}
@@ -406,7 +420,7 @@ class PublicationVersion extends JTable
 		{
 			$query.= " AND state!=3 ";
 		}
-		elseif (intval($exclude))
+		elseif (is_numeric($exclude))
 		{
 			$query.= " AND version_number!='".$exclude."' ";
 		}
@@ -458,7 +472,7 @@ class PublicationVersion extends JTable
 		{
 			$query.= " AND state=3 ";
 		}
-		elseif (intval($version))
+		elseif (is_numeric($version))
 		{
 			$query.= " AND version_number='".$version."' ";
 		}
@@ -532,7 +546,7 @@ class PublicationVersion extends JTable
 			$result = $this->_db->loadResult();
 			return $result ? true : false;
 		}
-		if (intval($version) > 0)
+		if (is_numeric($version))
 		{
 			$query  = "SELECT id FROM $this->_tbl WHERE publication_id = $pid AND version_number= $version LIMIT 1 ";
 			$this->_db->setQuery( $query );
@@ -638,7 +652,7 @@ class PublicationVersion extends JTable
 	 */
 	public function removeMainFlag( $vid = NULL, $unpublish = 0 )
 	{
-		if ($vid === NULL || intval($vid) == 0)
+		if ($vid === NULL || !is_numeric($vid) || intval($vid) == 0)
 		{
 			return false;
 		}
@@ -658,7 +672,7 @@ class PublicationVersion extends JTable
 	 */
 	public function getDefaultTitle( $projectid = 0, $title = '' )
 	{
-		if (intval($projectid) == 0)
+		if (!is_numeric($projectid) || intval($projectid) == 0)
 		{
 			return false;
 		}
@@ -737,7 +751,7 @@ class PublicationVersion extends JTable
 		{
 			$query.= " AND v.state=3 ";
 		}
-		elseif (intval($version))
+		elseif (is_numeric($version))
 		{
 			$query.= " AND v.version_number='".$version."' ";
 		}
@@ -806,7 +820,7 @@ class PublicationVersion extends JTable
 						}
 					}
 				}
-				if(!$found)
+				if (!$found)
 				{
 					$in .= n.$param.'='.$value;
 				}
