@@ -112,6 +112,7 @@ class AnswersControllerQuestions extends \Hubzero\Component\SiteController
 	 */
 	public function displayTask()
 	{
+		$this->_task = 'search';
 		$this->view->setLayout('search');
 		return $this->searchTask();
 	}
@@ -1258,14 +1259,27 @@ class AnswersControllerQuestions extends \Hubzero\Component\SiteController
 		JPluginHelper::importPlugin('xmessage');
 		$dispatcher = JDispatcher::getInstance();
 
+		// Notify the answerer and asker
 		if (!in_array($authorid, $receivers) && $question->get('email'))
 		{
-			if (!$dispatcher->trigger('onSendMessage', array('answers_reply_submitted', $subject, $message, $from, array($authorid), $this->_option)))
+			// Hide identity of destination if question is anonymously asked.
+			// MCRN Ticket #134
+			if ($question->get('anonymous') == '1')
+			{
+				$messageType = 'answers_reply_submitted_anonymous';
+			}
+			else
+			{
+				$messageType = 'answers_reply_submitted';
+			}
+
+			if (!$dispatcher->trigger('onSendMessage', array($messageType , $subject, $message, $from, array($authorid), $this->_option)))
 			{
 				$this->setError(JText::_('COM_ANSWERS_MESSAGE_FAILED'));
 			}
 		}
 
+		// Send answers admins a message
 		if (!empty($receivers))
 		{
 			if (!$dispatcher->trigger('onSendMessage', array('new_answer_admin', $subject, $message, $from, $receivers, $this->_option)))
@@ -1303,6 +1317,18 @@ class AnswersControllerQuestions extends \Hubzero\Component\SiteController
 
 		$question = new AnswersModelQuestion($id);
 
+		// check to see whether the author is accepting the answer.
+		if ($question->get('created_by') != $this->juser->get('id',0))
+		{
+			$this->setRedirect(
+				JRoute::_($question->link()),
+				JText::_('COM_ANSWERS_ERROR_MUST_BE_ASKER'),
+				'error'
+				);
+
+				return;
+		}
+
 		// Check changes
 		if (!$question->accept($rid))
 		{
