@@ -548,9 +548,10 @@ class CitationFormat
 		//do we have a title
 		if (isset($citation->title) && $citation->title != '')
 		{
-			if ($citation_type->type == 'journalarticle')
+			if ($citation_type->type == 'journal')
 			{
 				$query[] = 'atitle=' . str_replace(" ", "+", $citation->title);
+				$query[] = 'title=' . str_replace(" ", "+", $citation->journal);
 			}
 			else
 			{
@@ -583,7 +584,7 @@ class CitationFormat
 			}
 
 			//append to url as issn if journal otherwise as isbn
-			if ($citation_type->type == 'journalarticle')
+			if ($citation_type->type == 'journal')
 			{
 				$query[] = 'issn=' . $issn_isbn;
 			}
@@ -620,8 +621,13 @@ class CitationFormat
 		//do we have a link with some data to send to resolver?
 		if (count($query) > 0)
 		{
+			if (substr($link, -1, 1) != "?")
+			{
+				$link .= "?";
+			}
+
 			//add parts to url
-			$link .= "?" . implode("&", $query);
+			$link .= implode("&", $query);
 
 			//do we have an icon or just using text as the link
 			//$link_text = ($icon != '') ? '<img src="' . $icon . '" />' : $text;
