@@ -47,6 +47,7 @@ class CollectionsControllerMedia extends \Hubzero\Component\SiteController
 	{
 		$file = JRequest::getVar('file', '');
 		$item = JRequest::getInt('post', 0);
+		$size = JRequest::getWord('size', '');
 
 		$post = CollectionsModelPost::getInstance($item);
 
@@ -81,8 +82,10 @@ class CollectionsControllerMedia extends \Hubzero\Component\SiteController
 			return;
 		}
 
+		$file = $asset->file($size);
+
 		// Get the configured upload path
-		$filename = JPATH_ROOT . DS . trim($this->config->get('filepath', '/site/collections'), DS) . DS . $asset->get('item_id') . DS . ltrim($asset->get('filename'), DS);
+		$filename = $asset->filespace() . DS . $asset->get('item_id') . DS . ltrim($file, DS);
 
 		// Ensure the file exist
 		if (!file_exists($filename))
@@ -149,6 +152,7 @@ class CollectionsControllerMedia extends \Hubzero\Component\SiteController
 			if (!$item->exists())
 			{
 				$item->set('state', 0);
+				$item->set('access', 0);
 				$item->set('title', $listdir);
 				if (!$item->store())
 				{
@@ -203,6 +207,7 @@ class CollectionsControllerMedia extends \Hubzero\Component\SiteController
 			{
 				$item->set('id', 0);
 				$item->set('state', 0);
+				$item->set('access', 0);
 				$item->set('title', $listdir);
 				if (!$item->store())
 				{
@@ -277,6 +282,7 @@ class CollectionsControllerMedia extends \Hubzero\Component\SiteController
 			if (!$item->exists())
 			{
 				$item->set('state', 0);
+				$item->set('access', 0);
 				$item->set('title', $listdir);
 				if (!$item->store())
 				{
@@ -383,6 +389,15 @@ class CollectionsControllerMedia extends \Hubzero\Component\SiteController
 		$asset = new CollectionsModelAsset();
 		$asset->set('item_id', intval($listdir));
 		$asset->set('filename', $filename . '.' . $ext);
+		if ($asset->image())
+		{
+			$hi = new \Hubzero\Image\Processor($file);
+			if (count($hi->getErrors()) == 0)
+			{
+				$hi->autoRotate();
+				$hi->save();
+			}
+		}
 		$asset->set('description', JRequest::getVar('description', '', 'post'));
 		$asset->set('state', 1);
 		$asset->set('type', 'file');
@@ -484,6 +499,15 @@ class CollectionsControllerMedia extends \Hubzero\Component\SiteController
 			$asset = new CollectionsModelAsset();
 			$asset->set('item_id', intval($listdir));
 			$asset->set('filename', $file['name']);
+			if ($asset->image())
+			{
+				$hi = new \Hubzero\Image\Processor($path . DS . $file['name']);
+				if (count($hi->getErrors()) == 0)
+				{
+					$hi->autoRotate();
+					$hi->save();
+				}
+			}
 			$asset->set('description', JRequest::getVar('description', '', 'post'));
 			$asset->set('state', 1);
 			$asset->set('type', 'file');
