@@ -86,37 +86,25 @@ $base = 'index.php?option=' . $this->option . '&controller=' . $this->controller
 		table { border-collapse: collapse; mso-table-lspace: 0pt; mso-table-rspace: 0pt; }
 
 		@media only screen and (max-device-width: 480px) {
-			/*body { -webkit-text-size-adjust: 140% !important; }*/
-			/* Step 1: Reset colors */
-			a[href^="tel"], a[href^="sms"] {
-				text-decoration: none;
-				color: #333; /* or whatever your want */
-				pointer-events: none;
-				cursor: default;
+			body {
+				-webkit-text-size-adjust: 100% !important;
+				-ms-text-size-adjust: 100% !important;
+				font-size: 100% !important;
 			}
-			/* Step 2: Set colors for inteded items */
-			.mobile_link a[href^="tel"], .mobile_link a[href^="sms"] {
-				text-decoration: default;
-				color: #0fa1ca !important;
-				pointer-events: auto;
-				cursor: default;
+			table.tbl-wrap,
+			table.tbl-wrap td.tbl-body {
+				width: auto !important;
+				margin: 0 2em !important;
+			}
+			table.tbl-header td {
+				width: auto !important;
+			}
+			td.tbl-body .mobilehide {
+				display: none !important;
 			}
 		}
 		@media only screen and (min-device-width: 768px) and (max-device-width: 1024px) {
 			/* tablets, smaller screens, etc */
-			/* Step 1a: Repeating for the iPad */
-			a[href^="tel"], a[href^="sms"] {
-				text-decoration: none;
-				color: #333;
-				pointer-events: none;
-				cursor: default;
-			}
-			.mobile_link a[href^="tel"], .mobile_link a[href^="sms"] {
-				text-decoration: default;
-				color: #0fa1ca !important;
-				pointer-events: auto;
-				cursor: default;
-			}
 		}
 		</style>
 
@@ -146,14 +134,14 @@ $base = 'index.php?option=' . $this->option . '&controller=' . $this->controller
 					<td bgcolor="#ffffff" align="center" style="border-collapse: collapse;">
 
 						<!-- Start Content Wrapper Table -->
-						<table width="670" cellpadding="0" cellspacing="0" border="0" style="border-collapse: collapse;">
+						<table class="tbl-wrap" width="670" cellpadding="0" cellspacing="0" border="0" style="border-collapse: collapse;">
 							<tbody>
 								<tr style="border-collapse: collapse;">
 									<td bgcolor="#ffffff" width="10" style="border-collapse: collapse;"></td>
-									<td bgcolor="#ffffff" width="650" align="left" style="border-collapse: collapse;">
+									<td class="tbl-body" bgcolor="#ffffff" width="650" align="left" style="border-collapse: collapse;">
 
 										<!-- Start Header Spacer -->
-										<table  width="650" cellpadding="0" cellspacing="0" border="0">
+										<table  width="100%" cellpadding="0" cellspacing="0" border="0">
 											<tr style="border-collapse: collapse;">
 												<td height="30" style="border-collapse: collapse;"></td>
 											</tr>
@@ -161,13 +149,13 @@ $base = 'index.php?option=' . $this->option . '&controller=' . $this->controller
 										<!-- End Header Spacer -->
 
 										<!-- Start Header -->
-										<table cellpadding="2" cellspacing="3" border="0" width="100%" style="border-collapse: collapse; border-bottom: 2px solid #e1e1e1;">
+										<table class="tbl-header" cellpadding="2" cellspacing="3" border="0" width="100%" style="border-collapse: collapse; border-bottom: 2px solid #e1e1e1;">
 											<tbody>
 												<tr>
 													<td width="10%" nowrap="nowrap" align="left" valign="bottom" style="font-size: 1.4em; color: #999; padding: 0 10px 5px 0; text-align: left;">
 														<?php echo $jconfig->getValue('config.sitename'); ?>
 													</td>
-													<td width="80%" align="left" valign="bottom" style="line-height: 1; padding: 0 0 5px 10px;">
+													<td class="mobilehide" width="80%" align="left" valign="bottom" style="line-height: 1; padding: 0 0 5px 10px;">
 														<span style="font-weight: bold; font-size: 0.85em; color: #666; -webkit-text-size-adjust: none;">
 															<a href="<?php echo $juri->base(); ?>" style="color: #666; font-weight: bold; text-decoration: none; border: none;"><?php echo $juri->base(); ?></a>
 														</span>
@@ -183,14 +171,14 @@ $base = 'index.php?option=' . $this->option . '&controller=' . $this->controller
 										<!-- End Header -->
 
 										<!-- Start Header Spacer -->
-										<table  width="650" cellpadding="0" cellspacing="0" border="0">
+										<table  width="100%" cellpadding="0" cellspacing="0" border="0">
 											<tr style="border-collapse: collapse;">
 												<td height="30" style="border-collapse: collapse;"></td>
 											</tr>
 										</table>
 										<!-- End Header Spacer -->
 										<!-- Start Header -->
-										<table width="650" cellpadding="2" cellspacing="3" border="0" style="border-collapse: collapse;">
+										<table width="100%" cellpadding="2" cellspacing="3" border="0" style="border-collapse: collapse;">
 											<tbody>
 												<tr>
 													<td align="left" valign="bottom" style="border-collapse: collapse; color: #666; line-height: 1; padding: 5px; text-align: center;">
@@ -201,7 +189,7 @@ $base = 'index.php?option=' . $this->option . '&controller=' . $this->controller
 										</table>
 										<!-- End Header -->
 										<!-- Start Header Spacer -->
-										<table  width="650" cellpadding="0" cellspacing="0" border="0">
+										<table  width="100%" cellpadding="0" cellspacing="0" border="0">
 											<tr style="border-collapse: collapse;">
 												<td height="30" style="border-collapse: collapse;"></td>
 											</tr>
@@ -234,7 +222,7 @@ $base = 'index.php?option=' . $this->option . '&controller=' . $this->controller
 										$st = new SupportModelTags($ticket->id);
 										$tags = $st->render('string');
 								?>
-										<table id="ticket-info" width="650" cellpadding="0" cellspacing="0" border="0" style="border-collapse: collapse; border: 1px solid <?php echo $bdcolor['critical']; ?>; background: <?php echo $bgcolor['critical']; ?>; font-size: 0.9em; line-height: 1.6em;
+										<table id="ticket-info" width="100%" cellpadding="0" cellspacing="0" border="0" style="border-collapse: collapse; border: 1px solid <?php echo $bdcolor['critical']; ?>; background: <?php echo $bgcolor['critical']; ?>; font-size: 0.9em; line-height: 1.6em;
 											background-image: -webkit-gradient(linear, 0 0, 100% 100%, color-stop(.25, rgba(255, 255, 255, .075)), color-stop(.25, transparent), color-stop(.5, transparent), color-stop(.5, rgba(255, 255, 255, .075)), color-stop(.75, rgba(255, 255, 255, .075)), color-stop(.75, transparent), to(transparent));
 											background-image: -webkit-linear-gradient(-45deg, rgba(255, 255, 255, .075) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, .075) 50%, rgba(255, 255, 255, .075) 75%, transparent 75%, transparent);
 											background-image: -moz-linear-gradient(-45deg, rgba(255, 255, 255, .075) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, .075) 50%, rgba(255, 255, 255, .075) 75%, transparent 75%, transparent);
@@ -287,7 +275,7 @@ $base = 'index.php?option=' . $this->option . '&controller=' . $this->controller
 										</table>
 
 										<!-- Start Footer Spacer -->
-										<table  width="650" cellpadding="0" cellspacing="0" border="0">
+										<table  width="100%" cellpadding="0" cellspacing="0" border="0">
 											<tr style="border-collapse: collapse;">
 												<td height="10" style="border-collapse: collapse;"></td>
 											</tr>
@@ -323,7 +311,7 @@ $base = 'index.php?option=' . $this->option . '&controller=' . $this->controller
 										$st = new SupportModelTags($ticket->id);
 										$tags = $st->render('string');
 								?>
-										<table id="ticket-info" width="650" cellpadding="0" cellspacing="0" border="0" style="border-collapse: collapse; border: 1px solid <?php echo $bdcolor['major']; ?>; background: <?php echo $bgcolor['major']; ?>; font-size: 0.9em; line-height: 1.6em;
+										<table id="ticket-info" width="100%" cellpadding="0" cellspacing="0" border="0" style="border-collapse: collapse; border: 1px solid <?php echo $bdcolor['major']; ?>; background: <?php echo $bgcolor['major']; ?>; font-size: 0.9em; line-height: 1.6em;
 											background-image: -webkit-gradient(linear, 0 0, 100% 100%, color-stop(.25, rgba(255, 255, 255, .075)), color-stop(.25, transparent), color-stop(.5, transparent), color-stop(.5, rgba(255, 255, 255, .075)), color-stop(.75, rgba(255, 255, 255, .075)), color-stop(.75, transparent), to(transparent));
 											background-image: -webkit-linear-gradient(-45deg, rgba(255, 255, 255, .075) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, .075) 50%, rgba(255, 255, 255, .075) 75%, transparent 75%, transparent);
 											background-image: -moz-linear-gradient(-45deg, rgba(255, 255, 255, .075) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, .075) 50%, rgba(255, 255, 255, .075) 75%, transparent 75%, transparent);
@@ -376,7 +364,7 @@ $base = 'index.php?option=' . $this->option . '&controller=' . $this->controller
 										</table>
 
 										<!-- Start Footer Spacer -->
-										<table  width="650" cellpadding="0" cellspacing="0" border="0">
+										<table  width="100%" cellpadding="0" cellspacing="0" border="0">
 											<tr style="border-collapse: collapse;">
 												<td height="10" style="border-collapse: collapse;"></td>
 											</tr>
@@ -390,7 +378,7 @@ $base = 'index.php?option=' . $this->option . '&controller=' . $this->controller
 								{
 								?>
 										<!-- Start Footer Spacer -->
-										<table  width="650" cellpadding="0" cellspacing="0" border="0">
+										<table  width="100%" cellpadding="0" cellspacing="0" border="0">
 											<tr style="border-collapse: collapse;">
 												<td height="20" style="border-collapse: collapse;"></td>
 											</tr>
@@ -442,7 +430,7 @@ $base = 'index.php?option=' . $this->option . '&controller=' . $this->controller
 										$sef = JRoute::_($base . $ticket->id);
 										$link = rtrim($juri->base(), DS) . DS . trim($sef, DS);
 								?>
-										<table id="ticket-info" width="650" cellpadding="0" cellspacing="0" border="0" style="border-collapse: collapse; border: 1px solid <?php echo $bdcolor[$severity]; ?>; background: <?php echo $bgcolor[$severity]; ?>; font-size: 0.9em; line-height: 1.6em;
+										<table id="ticket-info" width="100%" cellpadding="0" cellspacing="0" border="0" style="border-collapse: collapse; border: 1px solid <?php echo $bdcolor[$severity]; ?>; background: <?php echo $bgcolor[$severity]; ?>; font-size: 0.9em; line-height: 1.6em;
 											background-image: -webkit-gradient(linear, 0 0, 100% 100%, color-stop(.25, rgba(255, 255, 255, .075)), color-stop(.25, transparent), color-stop(.5, transparent), color-stop(.5, rgba(255, 255, 255, .075)), color-stop(.75, rgba(255, 255, 255, .075)), color-stop(.75, transparent), to(transparent));
 											background-image: -webkit-linear-gradient(-45deg, rgba(255, 255, 255, .075) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, .075) 50%, rgba(255, 255, 255, .075) 75%, transparent 75%, transparent);
 											background-image: -moz-linear-gradient(-45deg, rgba(255, 255, 255, .075) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, .075) 50%, rgba(255, 255, 255, .075) 75%, transparent 75%, transparent);
@@ -471,7 +459,7 @@ $base = 'index.php?option=' . $this->option . '&controller=' . $this->controller
 										</table>
 
 										<!-- Start Footer Spacer -->
-										<table  width="650" cellpadding="0" cellspacing="0" border="0">
+										<table  width="100%" cellpadding="0" cellspacing="0" border="0">
 											<tr style="border-collapse: collapse;">
 												<td height="10" style="border-collapse: collapse;"></td>
 											</tr>
@@ -487,7 +475,7 @@ $base = 'index.php?option=' . $this->option . '&controller=' . $this->controller
 								?>
 								<?php if ($more) { ?>
 										<!-- Start Header -->
-										<table width="650" cellpadding="2" cellspacing="3" border="0" style="border-collapse: collapse; text-align: center;">
+										<table width="100%" cellpadding="2" cellspacing="3" border="0" style="border-collapse: collapse; text-align: center;">
 											<tbody>
 												<tr>
 													<td align="left" valign="bottom" style="line-height: 1; padding: 5px;">
@@ -500,7 +488,7 @@ $base = 'index.php?option=' . $this->option . '&controller=' . $this->controller
 								<?php } ?>
 
 										<!-- Start Footer Spacer -->
-										<table  width="650" cellpadding="0" cellspacing="0" border="0">
+										<table  width="100%" cellpadding="0" cellspacing="0" border="0">
 											<tr style="border-collapse: collapse;">
 												<td height="20" style="border-collapse: collapse;"></td>
 											</tr>
@@ -508,7 +496,7 @@ $base = 'index.php?option=' . $this->option . '&controller=' . $this->controller
 										<!-- End Footer Spacer -->
 
 										<!-- Start Header -->
-										<table width="650" cellpadding="2" cellspacing="3" border="0" style="border-collapse: collapse; border-top: 2px solid #e1e1e1;">
+										<table width="100%" cellpadding="2" cellspacing="3" border="0" style="border-collapse: collapse; border-top: 2px solid #e1e1e1;">
 											<tbody>
 												<tr>
 													<td align="left" valign="bottom" style="line-height: 1; padding: 5px 0 0 0; ">
@@ -520,7 +508,7 @@ $base = 'index.php?option=' . $this->option . '&controller=' . $this->controller
 										<!-- End Header -->
 
 										<!-- Start Footer Spacer -->
-										<table width="650" cellpadding="0" cellspacing="0" border="0">
+										<table width="100%" cellpadding="0" cellspacing="0" border="0">
 											<tbody>
 												<tr style="border-collapse: collapse;">
 													<td height="30" style="border-collapse: collapse; color: #fff !important;"><div style="height: 30px !important; visibility: hidden;">----</div></td>
@@ -540,10 +528,5 @@ $base = 'index.php?option=' . $this->option . '&controller=' . $this->controller
 			</tbody>
 		</table>
 		<!-- End Body Wrapper Table -->
-		<style type="text/css">
-		body { width: 100% !important; font-family: 'Helvetica Neue', Helvetica, Verdana, Arial, sans-serif !important; background-color: #ffffff !important; margin: 0 !important; padding: 0 !important; }
-		img { outline: none !important; text-decoration: none !important; display: block !important; }
-		@media only screen and (min-device-width: 481px) { body { -webkit-text-size-adjust: 140% !important; } }
-		</style>
 	</body>
 </html>
\ No newline at end of file
