@@ -36,67 +36,11 @@ defined('_JEXEC') or die('Restricted access');
  */
 class TagsTableObject extends JTable
 {
-	/**
-	 * int(11)
-	 *
-	 * @var integer
-	 */
-	var $id       = NULL;
-
-	/**
-	 * int(11)
-	 *
-	 * @var integer
-	 */
-	var $objectid = NULL;
-
-	/**
-	 * int(11)
-	 *
-	 * @var integer
-	 */
-	var $tagid    = NULL;
-
-	/**
-	 * tinyint(3)
-	 *
-	 * @var integer
-	 */
-	var $strength = NULL;
-
-	/**
-	 * int(11)
-	 *
-	 * @var integer
-	 */
-	var $taggerid = NULL;
-
-	/**
-	 * datetime(0000-00-00 00:00:00)
-	 *
-	 * @var string
-	 */
-	var $taggedon = NULL;
-
-	/**
-	 * varchar(255)
-	 *
-	 * @var string
-	 */
-	var $tbl      = NULL;
-
-	/**
-	 * varchar(255)
-	 *
-	 * @var string
-	 */
-	var $label    = NULL;
-
 	/**
 	 * Constructor
 	 *
-	 * @param      object &$db JDatabase
-	 * @return     void
+	 * @param   object  &$db  JDatabase
+	 * @return  void
 	 */
 	public function __construct(&$db)
 	{
@@ -106,7 +50,7 @@ class TagsTableObject extends JTable
 	/**
 	 * Validate data
 	 *
-	 * @return     True if data is valid
+	 * @return  True  if data is valid
 	 */
 	public function check()
 	{
@@ -151,8 +95,11 @@ class TagsTableObject extends JTable
 	 * Load a database row and populate this object with results
 	 * Uses unique tag string as identifier
 	 *
-	 * @param      string $oid Tag
-	 * @return     boolean True if tag found and loaded
+	 * @param   string   $tbl       Object type
+	 * @param   integer  $objectid  Object ID
+	 * @param   integer  $tagid     Tag ID
+	 * @param   integer  $taggerid  User ID
+	 * @return  boolean  True if tag found and loaded
 	 */
 	public function loadByObjectTag($tbl=null, $objectid=null, $tagid=null, $taggerid=null)
 	{
@@ -160,6 +107,7 @@ class TagsTableObject extends JTable
 		{
 			return false;
 		}
+
 		$query = "SELECT * FROM $this->_tbl
 				WHERE `tagid`=" . $this->_db->Quote((int) $tagid) . "
 				AND `objectid`=" . $this->_db->Quote((int) $objectid) . "
@@ -175,29 +123,25 @@ class TagsTableObject extends JTable
 		{
 			return $this->bind($result);
 		}
-		else
-		{
-			$this->setError($this->_db->getErrorMsg());
-			return false;
-		}
+
+		$this->setError($this->_db->getErrorMsg());
+		return false;
 	}
 
 	/**
 	 * Delete attachments to a tag
 	 *
-	 * @param      integer $tagid    Tag ID
-	 * @param      string  $tbl      Object type
-	 * @param      integer $objectid Object ID
-	 * @param      integer $taggerid Tagger ID
-	 * @param      boolean $admin    Admin authorization
-	 * @return     boolean True if records removed
+	 * @param   integer  $tagid     Tag ID
+	 * @param   string   $tbl       Object type
+	 * @param   integer  $objectid  Object ID
+	 * @param   integer  $taggerid  Tagger ID
+	 * @param   boolean  $admin     Admin authorization
+	 * @return  boolean  True if records removed
 	 */
 	public function deleteObjects($tagid=null, $tbl=null, $objectid=null, $taggerid=null, $admin=false)
 	{
-		if (!$tagid)
-		{
-			$tagid = $this->tagid;
-		}
+		$tagid = $tagid ?: $this->tagid;
+
 		if (!$tagid)
 		{
 			$this->setError(JText::_('Missing argument.'));
@@ -205,6 +149,7 @@ class TagsTableObject extends JTable
 		}
 
 		$sql = "DELETE FROM $this->_tbl WHERE tagid=" . $this->_db->Quote($tagid);
+
 		$filters = '';
 		if ($tbl)
 		{
@@ -230,14 +175,14 @@ class TagsTableObject extends JTable
 		}
 		else
 		{
-			require_once(JPATH_ROOT . DS . 'components' . DS . 'com_tags' . DS . 'tables' . DS . 'log.php');
+			require_once(__DIR__ . DS . 'log.php');
 
 			$data = new stdClass;
-			$data->tbl = $tbl;
+			$data->tbl      = $tbl;
 			$data->objectid = $objectid;
 			$data->taggerid = $taggerid;
-			$data->tagid = $tagid;
-			$data->entres = $items;
+			$data->tagid    = $tagid;
+			$data->entres   = $items;
 
 			$log = new TagsTableLog($this->_db);
 			$log->log($tagid, 'objects_removed', json_encode($data));
@@ -248,20 +193,16 @@ class TagsTableObject extends JTable
 	/**
 	 * Remove all tag references for a given object
 	 *
-	 * @param      string  $tbl      Object type
-	 * @param      integer $objectid Object ID
-	 * @return     boolean True if records removed
+	 * @param   string   $tbl        Object type
+	 * @param   integer  $objectid   Object ID
+	 * @param   integer  $tagger_id  Tagger ID
+	 * @return  boolean  True if records removed
 	 */
 	public function removeAllTags($tbl=null, $objectid=null, $tagger_id=null)
 	{
-		if (!$tbl)
-		{
-			$tbl = $this->tbl;
-		}
-		if (!$objectid)
-		{
-			$objectid = $this->objectid;
-		}
+		$tbl      = $tbl      ?: $this->tbl;
+		$objectid = $objectid ?: $this->objectid;
+
 		if (!$tbl || !$objectid)
 		{
 			$this->setError(JText::_('Missing argument.'));
@@ -291,12 +232,12 @@ class TagsTableObject extends JTable
 		}
 		else
 		{
-			require_once(JPATH_ROOT . DS . 'components' . DS . 'com_tags' . DS . 'tables' . DS . 'log.php');
+			require_once(__DIR__ . DS . 'log.php');
 
 			$data = new stdClass;
-			$data->tbl = $tbl;
+			$data->tbl      = $tbl;
 			$data->objectid = $objectid;
-			$data->entries = $items;
+			$data->entries  = $items;
 
 			$log = new TagsTableLog($this->_db);
 			$log->log($objectid, 'tags_removed', json_encode($data));
@@ -307,15 +248,13 @@ class TagsTableObject extends JTable
 	/**
 	 * Get a record count for a tag
 	 *
-	 * @param      integer $tagid Tag ID
-	 * @return     mixed Integer if successful, false if not
+	 * @param   integer  $tagid  Tag ID
+	 * @return  mixed    Integer if successful, false if not
 	 */
 	public function getCount($tagid=null)
 	{
-		if (!$tagid)
-		{
-			$tagid = $this->tagid;
-		}
+		$tagid = $tagid ?: $this->tagid;
+
 		if (!$tagid)
 		{
 			$this->setError(JText::_('Missing argument.'));
@@ -329,23 +268,18 @@ class TagsTableObject extends JTable
 	/**
 	 * Get all the tags on an object
 	 *
-	 * @param      integer $objectid Object ID
-	 * @param      string  $tbl      Object type
-	 * @param      integer $state    Admin authorization
-	 * @param      integer $offset   Where to start pulling records
-	 * @param      integer $limit    Number of records to pull
-	 * @return     mixed Array if successful, false if not
+	 * @param   integer  $objectid  Object ID
+	 * @param   string   $tbl       Object type
+	 * @param   integer  $state     Admin authorization
+	 * @param   integer  $offset    Where to start pulling records
+	 * @param   integer  $limit     Number of records to pull
+	 * @return  mixed    Array if successful, false if not
 	 */
 	public function getTagsOnObject($objectid=null, $tbl=null, $state=0, $offset=0, $limit=10)
 	{
-		if (!$objectid)
-		{
-			$objectid = $this->objectid;
-		}
-		if (!$tbl)
-		{
-			$tbl = $this->tbl;
-		}
+		$tbl      = $tbl      ?: $this->tbl;
+		$objectid = $objectid ?: $this->objectid;
+
 		if (!$tbl || !$objectid)
 		{
 			$this->setError(JText::_('Missing argument.'));
@@ -354,7 +288,7 @@ class TagsTableObject extends JTable
 
 		$sql = "SELECT DISTINCT t.*
 				FROM $this->_tbl AS rt
-				INNER JOIN #__tags AS t ON (rt.tagid = t.id)
+				INNER JOIN `#__tags` AS t ON (rt.tagid = t.id)
 				WHERE rt.objectid=" . $this->_db->Quote($objectid) . " AND rt.tbl=" . $this->_db->Quote($tbl);
 
 		if (isset($this->label))
@@ -371,6 +305,7 @@ class TagsTableObject extends JTable
 		{
 			$sql .= " LIMIT " . intval($offset) . ", " . intval($limit);
 		}
+
 		$this->_db->setQuery($sql);
 		return $this->_db->loadAssocList();
 	}
@@ -378,25 +313,17 @@ class TagsTableObject extends JTable
 	/**
 	 * Get a count of tags on an object
 	 *
-	 * @param      integer $tagid    Tag ID
-	 * @param      integer $objectid Object ID
-	 * @param      string  $tbl      Object type
-	 * @return     mixed Integer if successful, false if not
+	 * @param   integer  $tagid     Tag ID
+	 * @param   integer  $objectid  Object ID
+	 * @param   string   $tbl       Object type
+	 * @return  mixed    Integer if successful, false if not
 	 */
 	public function getCountForObject($tagid=null, $objectid=null, $tbl=null)
 	{
-		if (!$tagid)
-		{
-			$tagid = $this->tagid;
-		}
-		if (!$objectid)
-		{
-			$objectid = $this->objectid;
-		}
-		if (!$tbl)
-		{
-			$tbl = $this->tbl;
-		}
+		$tagid    = $tagid    ?: $this->tagid;
+		$tbl      = $tbl      ?: $this->tbl;
+		$objectid = $objectid ?: $this->objectid;
+
 		if (!$tagid || !$tbl || !$objectid)
 		{
 			$this->setError(JText::_('Missing argument.'));
@@ -410,21 +337,15 @@ class TagsTableObject extends JTable
 	/**
 	 * Move all references to one tag to another tag
 	 *
-	 * @param      integer $oldtagid ID of tag to be moved
-	 * @param      integer $newtagid ID of tag to move to
-	 * @return     boolean True if records changed
+	 * @param   integer  $oldtagid  ID of tag to be moved
+	 * @param   integer  $newtagid  ID of tag to move to
+	 * @return  boolean  True if records changed
 	 */
 	public function moveObjects($oldtagid=null, $newtagid=null)
 	{
-		if (!$oldtagid)
-		{
-			$oldtagid = $this->tagid;
-		}
-		if (!$oldtagid)
-		{
-			return false;
-		}
-		if (!$newtagid)
+		$oldtagid = $oldtagid ?: $this->tagid;
+
+		if (!$oldtagid || !$newtagid)
 		{
 			return false;
 		}
@@ -440,11 +361,11 @@ class TagsTableObject extends JTable
 		}
 		else
 		{
-			require_once(JPATH_ROOT . DS . 'components' . DS . 'com_tags' . DS . 'tables' . DS . 'log.php');
+			require_once(__DIR__ . DS . 'log.php');
 
 			$data = new stdClass;
-			$data->old_id = $oldtagid;
-			$data->new_id = $newtagid;
+			$data->old_id  = $oldtagid;
+			$data->new_id  = $newtagid;
 			$data->entries = $items;
 
 			$log = new TagsTableLog($this->_db);
@@ -456,28 +377,21 @@ class TagsTableObject extends JTable
 	/**
 	 * Copy all tags on an object to another object
 	 *
-	 * @param      integer $oldtagid ID of tag to be copied
-	 * @param      integer $newtagid ID of tag to copy to
-	 * @return     boolean True if records copied
+	 * @param   integer  $oldtagid  ID of tag to be copied
+	 * @param   integer  $newtagid  ID of tag to copy to
+	 * @return  boolean  True if records copied
 	 */
 	public function copyObjects($oldtagid=null, $newtagid=null)
 	{
-		if (!$oldtagid)
-		{
-			$oldtagid = $this->tagid;
-		}
-		if (!$oldtagid)
-		{
-			return false;
-		}
-		if (!$newtagid)
+		$oldtagid = $oldtagid ?: $this->tagid;
+
+		if (!$oldtagid || !$newtagid)
 		{
 			return false;
 		}
 
 		$this->_db->setQuery("SELECT * FROM $this->_tbl WHERE tagid=" . $this->_db->Quote($oldtagid));
-		$rows = $this->_db->loadObjectList();
-		if ($rows)
+		if ($rows = $this->_db->loadObjectList())
 		{
 			$entries = array();
 			foreach ($rows as $row)
@@ -488,15 +402,16 @@ class TagsTableObject extends JTable
 				$to->strength = $row->strength;
 				$to->taggerid = $row->taggerid;
 				$to->taggedon = $row->taggedon;
-				$to->tbl = $row->tbl;
+				$to->tbl      = $row->tbl;
 				$to->store();
+
 				$entries[] = $row->id;
 			}
-			require_once(JPATH_ROOT . DS . 'components' . DS . 'com_tags' . DS . 'tables' . DS . 'log.php');
+			require_once(__DIR__ . DS . 'log.php');
 
 			$data = new stdClass;
-			$data->old_id = $oldtagid;
-			$data->new_id = $newtagid;
+			$data->old_id  = $oldtagid;
+			$data->new_id  = $newtagid;
 			$data->entries = $entries;
 
 			$log = new TagsTableLog($this->_db);
@@ -508,13 +423,12 @@ class TagsTableObject extends JTable
 	/**
 	 * Build a query from filters
 	 *
-	 * @param      array $filters Filters to determien hwo to build query
-	 * @return     string SQL
+	 * @param   array   $filters  Filters to determien hwo to build query
+	 * @return  string  SQL
 	 */
 	public function _buildQuery($filters)
 	{
-		$query  = " FROM $this->_tbl AS o
-					INNER JOIN #__tags AS t ON (o.tagid = t.id)";
+		$query  = " FROM $this->_tbl AS o INNER JOIN #__tags AS t ON (o.tagid = t.id)";
 
 		$where = array();
 
@@ -545,6 +459,36 @@ class TagsTableObject extends JTable
 			$query .= implode(" AND ", $where);
 		}
 
+		return $query;
+	}
+
+	/**
+	 * Get a record count
+	 *
+	 * @param   array    $filters  Filters to determien hwo to build query
+	 * @return  integer
+	 */
+	public function count($filters=array())
+	{
+		$this->_db->setQuery("SELECT COUNT(*) " . $this->_buildQuery($filters));
+		return $this->_db->loadResult();
+	}
+
+	/**
+	 * Get records
+	 *
+	 * @param   array  $filters  Filters to determien hwo to build query
+	 * @return  array
+	 */
+	public function find($filters=array())
+	{
+		$query = "SELECT * " . $this->_buildQuery($filters);
+
+		if (!isset($filters['sort']) || $filters['sort'] == '')
+		{
+			$filters['sort'] = 'taggedon';
+		}
+
 		if (isset($filters['sort']) && $filters['sort'] != '')
 		{
 			if (!isset($filters['sort_Dir']) || !in_array(strtoupper($filters['sort_Dir']), array('ASC', 'DESC')))
@@ -563,38 +507,7 @@ class TagsTableObject extends JTable
 			$query .= " LIMIT " . $filters['start'] . "," . $filters['limit'];
 		}
 
-		return $query;
-	}
-
-	/**
-	 * Get a record count
-	 *
-	 * @param      array $filters Filters to determien hwo to build query
-	 * @return     integer
-	 */
-	public function count($filters=array())
-	{
-		$filters['limit'] = 0;
-		$filters['count'] = true;
-		$filters['sort']  = '';
-
-		$this->_db->setQuery("SELECT COUNT(*) " . $this->_buildQuery($filters));
-		return $this->_db->loadResult();
-	}
-
-	/**
-	 * Get records
-	 *
-	 * @param      array $filters Filters to determien hwo to build query
-	 * @return     array
-	 */
-	public function find($filters=array())
-	{
-		if (!isset($filters['sort']) || $filters['sort'] == '')
-		{
-			$filters['sort'] = 'taggedon';
-		}
-		$this->_db->setQuery("SELECT * " . $this->_buildQuery($filters));
+		$this->_db->setQuery($query);
 		return $this->_db->loadObjectList();
 	}
 }
