@@ -104,6 +104,11 @@ class WikiControllerHistory extends \Hubzero\Component\SiteController
 			return;
 		}
 
+		if (!$this->page->exists())
+		{
+			JError::raiseError(404, JText::_('COM_WIKI_WARNING_NOT_FOUND'));
+		}
+
 		$this->registerTask('deleterevision', 'delete');
 
 		parent::execute();
