@@ -66,7 +66,7 @@ $this->css();
 		<input type="hidden" name="option" value="<?php echo $this->option; ?>" />
 		<input type="hidden" name="active" value="<?php echo $this->name; ?>" />
 		<input type="hidden" name="action" value="delete" />
-		<input type="hidden" name="post" value="<?php echo $this->post->get('id'); ?>" />
+		<input type="hidden" name="post" value="<?php echo $this->escape($this->post->get('id')); ?>" />
 		<input type="hidden" name="no_html" value="<?php echo $this->no_html; ?>" />
 
 		<?php echo JHTML::_('form.token'); ?>
